@@ -1,8 +1,8 @@
 from pydantic import BaseModel, Field
 from typing import Annotated
 from maleo.enums.environment import Environment
-from maleo.types.dict import OptionalStringToStringDict
-from maleo.types.string import OptionalString
+from maleo.types.dict import OptStrToStrDict
+from maleo.types.string import OptStr
 
 
 class DatabaseIdentifierConfig(BaseModel):
@@ -14,8 +14,6 @@ class DatabaseIdentifierConfig(BaseModel):
     ]
     name: Annotated[str, Field(..., description="Database's name")]
     description: Annotated[
-        OptionalString, Field(None, description="Database's description")
-    ] = None
-    tags: Annotated[
-        OptionalStringToStringDict, Field(None, description="Database's tags")
+        OptStr, Field(None, description="Database's description")
     ] = None
+    tags: Annotated[OptStrToStrDict, Field(None, description="Database's tags")] = None
