@@ -7,13 +7,13 @@ from pymongo import MongoClient
 from redis.asyncio import Redis as AsyncRedis
 from redis import Redis as SyncRedis
 from sqlalchemy import text
-from typing import Generic, Type, TypeVar, Union
+from typing import Generic, Type, TypeVar
 from uuid import uuid4
 from maleo.logging.enums import Level
 from maleo.logging.logger import EnvironmentT, ServiceKeyT, Database
-from maleo.schemas.application import ApplicationContext, OptionalApplicationContext
-from maleo.schemas.connection import OptionalConnectionContext
-from maleo.schemas.error.enums import Code as ErrorCode
+from maleo.schemas.application import ApplicationContext, OptApplicationContext
+from maleo.schemas.connection import OptConnectionContext
+from maleo.schemas.error.enums import ErrorCode
 from maleo.schemas.exception.factory import Factory as MaleoExceptionFactory
 from maleo.schemas.operation.context import generate
 from maleo.schemas.operation.enums import (
@@ -29,10 +29,10 @@ from maleo.schemas.operation.system import (
     SuccessfulSystemOperation,
 )
 from maleo.schemas.response import NoDataResponse
-from maleo.schemas.security.authentication import OptionalAnyAuthentication
-from maleo.schemas.security.authorization import OptionalAnyAuthorization
-from maleo.schemas.security.impersonation import OptionalImpersonation
-from maleo.types.uuid import OptionalUUID
+from maleo.schemas.security.authentication import OptAnyAuthentication
+from maleo.schemas.security.authorization import OptAnyAuthorization
+from maleo.schemas.security.impersonation import OptImpersonation
+from maleo.types.uuid import OptUUID
 from maleo.utils.exception import extract_details
 from ..config import (
     MySQLConfig,
@@ -63,7 +63,7 @@ class Manager(ABC, Generic[DatabaseConfigT]):
         self,
         config: DatabaseConfigT,
         logger: Database[EnvironmentT, ServiceKeyT],
-        application_context: OptionalApplicationContext = None,
+        application_context: OptApplicationContext = None,
     ) -> None:
         super().__init__()
         self._config = config
@@ -82,22 +82,22 @@ class Manager(ABC, Generic[DatabaseConfigT]):
     @abstractmethod
     async def async_check_connection(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> bool:
         pass
 
     @abstractmethod
     def sync_check_connection(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> bool:
         pass
 
@@ -119,7 +119,7 @@ class NoSQLManager(
         self,
         config: NoSQLConfigT,
         logger: Database,
-        application_context: OptionalApplicationContext = None,
+        application_context: OptApplicationContext = None,
     ) -> None:
         super().__init__(config, logger, application_context)
         self._operation_context.target.details = self._config.model_dump()
@@ -131,11 +131,11 @@ class NoSQLManager(
 
     async def async_check_connection(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> bool:
         """Check client connectivity by executing a simple query."""
         client = self._client_manager.get(Connection.ASYNC)
@@ -164,11 +164,11 @@ class NoSQLManager(
 
     def sync_check_connection(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> bool:
         """Check client connectivity by executing a simple query."""
         client = self._client_manager.get(Connection.SYNC)
@@ -213,11 +213,7 @@ class RedisManager(NoSQLManager[RedisConfig, RedisClientManager]):
     client_manager_cls = RedisClientManager
 
 
-AnyNoSQLManager = Union[
-    ElasticsearchManager,
-    MongoManager,
-    RedisManager,
-]
+AnyNoSQLManager = ElasticsearchManager | MongoManager | RedisManager
 
 
 NoSQLManagerT = TypeVar("NoSQLManagerT", bound=AnyNoSQLManager)
@@ -229,7 +225,7 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
         Base: Type[DeclarativeBaseT],
         config: SQLConfigT,
         logger: Database,
-        application_context: OptionalApplicationContext = None,
+        application_context: OptApplicationContext = None,
     ) -> None:
         super().__init__(config, logger, application_context)
         self._operation_context.target.details = self._config.model_dump()
@@ -253,11 +249,11 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
 
     async def async_check_connection(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> bool:
         """Check database connectivity by executing a simple query."""
         operation_id = operation_id if operation_id is not None else uuid4()
@@ -310,11 +306,11 @@ class SQLManager(Manager[SQLConfigT], Generic[SQLConfigT, DeclarativeBaseT]):
 
     def sync_check_connection(
         self,
-        operation_id: OptionalUUID = None,
-        connection_context: OptionalConnectionContext = None,
-        authentication: OptionalAnyAuthentication = None,
-        authorization: OptionalAnyAuthorization = None,
-        impersonation: OptionalImpersonation = None,
+        operation_id: OptUUID = None,
+        connection_context: OptConnectionContext = None,
+        authentication: OptAnyAuthentication = None,
+        authorization: OptAnyAuthorization = None,
+        impersonation: OptImpersonation = None,
     ) -> bool:
         """Check database connectivity by executing a simple query."""
         operation_id = operation_id if operation_id is not None else uuid4()
@@ -394,18 +390,13 @@ class SQLServerManager(
     pass
 
 
-AnySQLManager = Union[
-    MySQLManager,
-    PostgreSQLManager,
-    SQLiteManager,
-    SQLServerManager,
-]
+AnySQLManager = MySQLManager | PostgreSQLManager | SQLiteManager | SQLServerManager
 
 
 SQLManagerT = TypeVar("SQLManagerT", bound=AnySQLManager)
 
 
-AnyDatabaseManager = Union[AnySQLManager, AnyNoSQLManager]
+AnyDatabaseManager = AnySQLManager | AnyNoSQLManager
 
 
 DatabaseManagerT = TypeVar("DatabaseManagerT", bound=AnyDatabaseManager)
