@@ -7,7 +7,13 @@ from contextlib import (
 from datetime import datetime, timezone
 from pydantic import ValidationError
 from sqlalchemy.engine import Engine
-from sqlalchemy.exc import SQLAlchemyError
+from sqlalchemy.exc import (
+    IntegrityError,
+    OperationalError,
+    ProgrammingError,
+    DatabaseError,
+    SQLAlchemyError,
+)
 from sqlalchemy.ext.asyncio import AsyncEngine, async_sessionmaker, AsyncSession
 from sqlalchemy.orm import sessionmaker, Session
 from typing import (
@@ -127,6 +133,82 @@ class SessionManager(Generic[SQLConfigT]):
                 impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
             ).log(self._logger, level=Level.INFO)
+        except IntegrityError as ie:
+            await session.rollback()
+            exc = MaleoExceptionFactory.from_code(
+                ErrorCode.CONFLICT,
+                details=extract_details(ie),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="IntegrityError occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from ie
+        except OperationalError as oe:
+            await session.rollback()
+            exc = MaleoExceptionFactory.from_code(
+                ErrorCode.SERVICE_UNAVAILABLE,
+                details=extract_details(oe),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="OperationalError occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from oe
+        except ProgrammingError as pe:
+            await session.rollback()
+            exc = MaleoExceptionFactory.from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
+                details=extract_details(pe),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="ProgrammingError occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from pe
+        except DatabaseError as de:
+            await session.rollback()
+            exc = MaleoExceptionFactory.from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
+                details=extract_details(de),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="DatabaseError occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from de
         except SQLAlchemyError as se:
             await session.rollback()
             exc = MaleoExceptionFactory.from_code(
@@ -251,8 +333,84 @@ class SessionManager(Generic[SQLConfigT]):
                 impersonation=impersonation,
                 response=NoDataResponse[None](metadata=None, other=None),
             ).log(self._logger, level=Level.INFO)
+        except IntegrityError as ie:
+            session.rollback()
+            exc = MaleoExceptionFactory.from_code(
+                ErrorCode.CONFLICT,
+                details=extract_details(ie),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="IntegrityError occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from ie
+        except OperationalError as oe:
+            session.rollback()
+            exc = MaleoExceptionFactory.from_code(
+                ErrorCode.SERVICE_UNAVAILABLE,
+                details=extract_details(oe),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="OperationalError occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from oe
+        except ProgrammingError as pe:
+            session.rollback()
+            exc = MaleoExceptionFactory.from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
+                details=extract_details(pe),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="ProgrammingError occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from pe
+        except DatabaseError as de:
+            session.rollback()
+            exc = MaleoExceptionFactory.from_code(
+                ErrorCode.INTERNAL_SERVER_ERROR,
+                details=extract_details(de),
+                operation_type=OperationType.SYSTEM,
+                application_context=self._application_context,
+                operation_id=operation_id,
+                operation_context=self._operation_context,
+                operation_action=operation_action,
+                operation_timestamp=Timestamp.completed_now(executed_at),
+                operation_summary="DatabaseError occured while handling async database session",
+                connection_context=connection_context,
+                authentication=authentication,
+                authorization=authorization,
+                impersonation=impersonation,
+            )
+            exc.operation.log(self._logger, level=Level.ERROR)
+            raise exc from de
         except SQLAlchemyError as se:
-            session.rollback()  # Rollback on error
+            session.rollback()
             exc = MaleoExceptionFactory.from_code(
                 ErrorCode.INTERNAL_SERVER_ERROR,
                 details=extract_details(se),
@@ -262,7 +420,7 @@ class SessionManager(Generic[SQLConfigT]):
                 operation_context=self._operation_context,
                 operation_action=operation_action,
                 operation_timestamp=Timestamp.completed_now(executed_at),
-                operation_summary="SQLAlchemy error occured while handling sync database session",
+                operation_summary="SQLAlchemy error occured while handling async database session",
                 connection_context=connection_context,
                 authentication=authentication,
                 authorization=authorization,
