@@ -1,4 +1,4 @@
-from sqlalchemy import asc, cast, desc, or_, select
+from sqlalchemy import and_, asc, cast, desc, or_, select
 from sqlalchemy.orm import aliased
 from sqlalchemy.orm.attributes import InstrumentedAttribute
 from sqlalchemy.sql import Select
@@ -8,21 +8,37 @@ from maleo.enums.order import Order
 from maleo.enums.status import OptListOfDataStatuses
 from maleo.schemas.mixins.filter import DateFilter
 from maleo.schemas.mixins.sort import SortColumn
+from maleo.types.any import ManyAny
 from maleo.types.boolean import OptBool
 from maleo.types.integer import OptListOfInts
-from maleo.types.string import OptListOfStrs, OptStr
-from .types import DeclarativeBaseT, RowT
+from maleo.types.string import OptListOfStrs, OptStr, ManyStrs
+from .types import DeclarativeBaseT, RowT, StmtTypeT
+
+
+def validate_column(
+    table: Type[DeclarativeBaseT],
+    column: str,
+) -> InstrumentedAttribute | None:
+    column_attr = getattr(table, column, None)
+    if column_attr is not None and isinstance(column_attr, InstrumentedAttribute):
+        return column_attr
+    return None
 
 
 def filter_column(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
     column: str,
     value: Any = None,
     include_null: bool = False,
-) -> Select[RowT]:
-    column_attr = getattr(table, column, None)
-    if column_attr is None or not isinstance(column_attr, InstrumentedAttribute):
+    strict: bool = True,
+) -> StmtTypeT:
+    column_attr = validate_column(table=table, column=column)
+    if column_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{column}' for table '{table.__tablename__}'"
+            )
         return stmt
 
     value_filters = []
@@ -37,15 +53,48 @@ def filter_column(
     return stmt
 
 
+def filter_columns(
+    stmt: StmtTypeT,
+    table: Type[DeclarativeBaseT],
+    columns: ManyStrs,
+    values: ManyAny,
+    strict: bool = True,
+    is_union: bool = False,
+) -> StmtTypeT:
+    if len(columns) != len(values):
+        raise ValueError("`columns` and `values` must have the same length")
+
+    filters = []
+    for column, value in zip(columns, values):
+        column_attr = validate_column(table=table, column=column)
+        if column_attr is None:
+            if strict:
+                raise AttributeError(
+                    f"Invalid column '{column}' for table '{table.__tablename__}'"
+                )
+            continue
+        filters.append(column_attr == value)
+
+    if filters:
+        stmt = stmt.filter(or_(*filters) if is_union else and_(*filters))
+
+    return stmt
+
+
 def filter_ids(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
     column: str,
     ids: OptListOfInts = None,
     include_null: bool = False,
-) -> Select[RowT]:
-    column_attr = getattr(table, column, None)
-    if column_attr is None or not isinstance(column_attr, InstrumentedAttribute):
+    strict: bool = True,
+) -> StmtTypeT:
+    column_attr = validate_column(table=table, column=column)
+    if column_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{column}' for table '{table.__tablename__}'"
+            )
         return stmt
 
     id_filters = []
@@ -61,10 +110,10 @@ def filter_ids(
 
 
 def filter_timestamps(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
     date_filters: Sequence[DateFilter],
-) -> Select[RowT]:
+) -> StmtTypeT:
     if date_filters:
         for date_filter in date_filters:
             try:
@@ -88,22 +137,39 @@ def filter_timestamps(
 
 
 def filter_statuses(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
-    statuses: OptListOfDataStatuses,
-) -> Select[RowT]:
+    column: str = "status",
+    statuses: OptListOfDataStatuses = None,
+    strict: bool = True,
+) -> StmtTypeT:
+    column_attr = validate_column(table=table, column=column)
+    if column_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{column}' for table '{table.__tablename__}'"
+            )
+        return stmt
     if statuses is not None:
-        status_filters = [table.status == status for status in statuses]  # type: ignore
+        status_filters = [column_attr == status for status in statuses]
         stmt = stmt.filter(or_(*status_filters))
     return stmt
 
 
 def filter_is_root(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
     parent_column: str = "parent_id",
     is_root: OptBool = None,
-) -> Select[RowT]:
+    strict: bool = True,
+) -> StmtTypeT:
+    parent_attr = validate_column(table=table, column=parent_column)
+    if parent_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{parent_column}' for table '{table.__tablename__}'"
+            )
+        return stmt
     parent_attr = getattr(table, parent_column, None)
     if parent_attr is None or not isinstance(parent_attr, InstrumentedAttribute):
         return stmt
@@ -115,17 +181,26 @@ def filter_is_root(
 
 
 def filter_is_parent(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
     id_column: str = "id",
     parent_column: str = "parent_id",
     is_parent: OptBool = None,
-) -> Select[RowT]:
-    id_attr = getattr(table, id_column, None)
-    if id_attr is None or not isinstance(id_attr, InstrumentedAttribute):
+    strict: bool = True,
+) -> StmtTypeT:
+    id_attr = validate_column(table=table, column=id_column)
+    if id_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{id_column}' for table '{table.__tablename__}'"
+            )
         return stmt
-    parent_attr = getattr(table, parent_column, None)
-    if parent_attr is None or not isinstance(parent_attr, InstrumentedAttribute):
+    parent_attr = validate_column(table=table, column=parent_column)
+    if parent_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{parent_column}' for table '{table.__tablename__}'"
+            )
         return stmt
     if is_parent is not None:
         child_table = aliased(table)
@@ -136,13 +211,18 @@ def filter_is_parent(
 
 
 def filter_is_child(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
     parent_column: str = "parent_id",
     is_child: OptBool = None,
-) -> Select[RowT]:
-    parent_attr = getattr(table, parent_column, None)
-    if parent_attr is None or not isinstance(parent_attr, InstrumentedAttribute):
+    strict: bool = True,
+) -> StmtTypeT:
+    parent_attr = validate_column(table=table, column=parent_column)
+    if parent_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{parent_column}' for table '{table.__tablename__}'"
+            )
         return stmt
     if is_child is not None:
         stmt = stmt.filter(
@@ -152,17 +232,26 @@ def filter_is_child(
 
 
 def filter_is_leaf(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
     id_column: str = "id",
     parent_column: str = "parent_id",
     is_leaf: OptBool = None,
-) -> Select[RowT]:
-    id_attr = getattr(table, id_column, None)
-    if id_attr is None or not isinstance(id_attr, InstrumentedAttribute):
+    strict: bool = True,
+) -> StmtTypeT:
+    id_attr = validate_column(table=table, column=id_column)
+    if id_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{id_column}' for table '{table.__tablename__}'"
+            )
         return stmt
-    parent_attr = getattr(table, parent_column, None)
-    if parent_attr is None or not isinstance(parent_attr, InstrumentedAttribute):
+    parent_attr = validate_column(table=table, column=parent_column)
+    if parent_attr is None:
+        if strict:
+            raise AttributeError(
+                f"Invalid column '{parent_column}' for table '{table.__tablename__}'"
+            )
         return stmt
     if is_leaf is not None:
         child_table = aliased(table)
@@ -173,11 +262,11 @@ def filter_is_leaf(
 
 
 def search(
-    stmt: Select[RowT],
+    stmt: StmtTypeT,
     table: Type[DeclarativeBaseT],
     search: OptStr = None,
     columns: OptListOfStrs = None,
-) -> Select[RowT]:
+) -> StmtTypeT:
     if search is None:
         return stmt
 
