@@ -1,12 +1,12 @@
 from typing import Literal, overload
-from maleo.types.string import ListOfStrings, OptionalString
+from maleo.types.string import ListOfStrs, OptStr
 from .enums import CacheOrigin, CacheLayer
 
 
 @overload
 def build_cache_namespace(
     *ext: str,
-    base: OptionalString = None,
+    base: OptStr = None,
     origin: Literal[CacheOrigin.SERVICE],
     layer: CacheLayer,
     sep: str = ":",
@@ -14,7 +14,7 @@ def build_cache_namespace(
 @overload
 def build_cache_namespace(
     *ext: str,
-    base: OptionalString = None,
+    base: OptStr = None,
     client: str,
     origin: Literal[CacheOrigin.CLIENT],
     layer: CacheLayer,
@@ -22,13 +22,13 @@ def build_cache_namespace(
 ) -> str: ...
 def build_cache_namespace(
     *ext: str,
-    base: OptionalString = None,
-    client: OptionalString = None,
+    base: OptStr = None,
+    client: OptStr = None,
     origin: CacheOrigin,
     layer: CacheLayer,
     sep: str = ":",
 ) -> str:
-    slugs: ListOfStrings = []
+    slugs: ListOfStrs = []
     if base is not None:
         slugs.append(base)
     slugs.extend([origin, layer])
